@@ -16,8 +16,8 @@ class Model(object):
         self.__select = []
         self.__update = {}
         self.__where = []
-        self.__order = {}
-        self.__group = {}
+        self.__order = ''
+        self.__group = ''
         self.__having = ''
         self.__offset = ''
         self.__limit = ''
@@ -159,6 +159,12 @@ class Model(object):
                 for v in cond['value']:
                     v_list.append(f"'{v}'")
                 cond_list.append(f"{cond['field']} {cond['op']} ({','.join(v_list)})")
+            elif cond['op'] == 'between':
+                if not isinstance(cond['value'], list):
+                    raise Exception('condition in or not in should be a list')
+                if len(cond['value']) != 2:
+                    raise Exception('condition should have two element')
+                cond_list.append(f"{cond['field']} between '{cond['value'][0]}' and '{cond['value'][1]}'")
         where_sql = ' and '.join(cond_list)
         if where_sql:
             sql = f"where {where_sql} "
@@ -325,8 +331,10 @@ class Model(object):
 
             if field.find('.'):
                 field = '.'.join([f"`{v}`" for v in field.split('.')])
+            op = args[1].lower()
+            op = ' '.join([o for o in op.split()])
             cond = dict()
-            cond['op'] = args[1]
+            cond['op'] = op
             cond['field'] = field
             cond['value'] = value
             self.__where.append(cond)
@@ -346,7 +354,7 @@ class Model(object):
         return self
 
     def group(self, group):
-        self.__group = group
+        self.__group = f"`{group}`"
         return self
 
     def having(self, *args):
@@ -388,7 +396,10 @@ class Model(object):
         sql += self.__build_join_sql()
         sql += self.__build_where_sql()
         sql += self.__build_other_sql()
-        self.__sql = sql.strip()
+        if self.__group:
+            self.__sql = f"select count(*) from ({sql.strip()}) as `_t`"
+        else:
+            self.__sql = sql.strip()
         return self.__conn.count(self.__sql)
 
     def __build_simple_sql(self, field, func=''):
@@ -418,6 +429,10 @@ class Model(object):
         sql += self.__build_other_sql()
         return sql.strip()
 
+    def sum(self, field):
+        self.__sql = self.__build_simple_sql(field, 'sum')
+        return self.__conn.sum(self.__sql)
+
     def min(self, field):
         self.__sql = self.__build_simple_sql(field, 'min')
         return self.__conn.min(self.__sql)
