@@ -5,7 +5,7 @@ from models.user import User
 
 if __name__ == '__main__':
 
-    Database().connect(**db)
+    Database.connect(**db)
 
     exists = User.find().where(name='ping').exists()
     print(exists)
